@@ -64,17 +64,19 @@ class FirewallCommand(object):
     def print_warning(self, msg=None):
         FAIL = '\033[91m'
         END = '\033[00m'
-        self.print_error_msg(FAIL + msg + END)
+        if sys.stderr.isatty():
+            msg = FAIL + msg + END
+        self.print_error_msg(msg)
 
     def print_and_exit(self, msg=None, exit_code=0):
         #OK = '\033[92m'
-        FAIL = '\033[91m'
-        END = '\033[00m'
+        #END = '\033[00m'
         if exit_code > 1:
-            self.print_error_msg(FAIL + msg + END)
+            self.print_warning(msg)
         else:
+            #if sys.stdout.isatty():
+            #   msg = OK + msg + END
             self.print_msg(msg)
-            #self.print_msg(OK + msg + END)
         sys.exit(exit_code)
 
     def fail(self, msg=None):
@@ -273,26 +275,35 @@ class FirewallCommand(object):
                                 proto)
         return (port, proto)
 
-    def parse_forward_port(self, value):
+    def parse_forward_port(self, value, compat=False):
         port = None
         protocol = None
         toport = None
         toaddr = None
-        args = value.split(":")
-        for arg in args:
-            try:
-                (opt, val) = arg.split("=")
-                if opt == "port":
-                    port = val
-                elif opt == "proto":
-                    protocol = val
-                elif opt == "toport":
-                    toport = val
-                elif opt == "toaddr":
-                    toaddr = val
-            except ValueError:
+        i = 0
+        while ("=" in value[i:]):
+            opt = value[i:].split("=", 1)[0]
+            i += len(opt) + 1
+            if "=" in value[i:]:
+                val = value[i:].split(":", 1)[0]
+            else:
+                val = value[i:]
+            i += len(val) + 1
+
+            if opt == "port":
+                port = val
+            elif opt == "proto":
+                protocol = val
+            elif opt == "toport":
+                toport = val
+            elif opt == "toaddr":
+                toaddr = val
+            elif opt == "if" and compat:
+                # ignore if option in compat mode
+                pass
+            else:
                 raise FirewallError(errors.INVALID_FORWARD,
-                                    "invalid forward port arg '%s'" % (arg))
+                                    "invalid forward port arg '%s'" % (opt))
         if not port:
             raise FirewallError(errors.INVALID_FORWARD, "missing port")
         if not protocol:
@@ -309,7 +320,8 @@ class FirewallCommand(object):
         if toport and not check_port(toport):
             raise FirewallError(errors.INVALID_PORT, toport)
         if toaddr and not check_single_address("ipv4", toaddr):
-            raise FirewallError(errors.INVALID_ADDR, toaddr)
+            if compat or not check_single_address("ipv6", toaddr):
+                raise FirewallError(errors.INVALID_ADDR, toaddr)
 
         return (port, protocol, toport, toaddr)
 
@@ -365,10 +377,10 @@ class FirewallCommand(object):
                                 "Module name '%s' too short" % value)
         return value
 
-    def print_zone_info(self, zone, settings, default_zone=None): # pylint: disable=R0914
+    def print_zone_info(self, zone, settings, default_zone=None, extra_interfaces=[]): # pylint: disable=R0914
         target = settings.getTarget()
         icmp_block_inversion = settings.getIcmpBlockInversion()
-        interfaces = settings.getInterfaces()
+        interfaces = sorted(set(settings.getInterfaces() + extra_interfaces))
         sources = settings.getSources()
         services = settings.getServices()
         ports = settings.getPorts()
@@ -381,6 +393,19 @@ class FirewallCommand(object):
         description = settings.getDescription()
         short_description = settings.getShort()
 
+        def rich_rule_sorted_key(rule):
+            priority = 0
+            search_str = "priority="
+            try:
+                i = rule.index(search_str)
+            except ValueError:
+                pass
+            else:
+                i += len(search_str)
+                priority = int(rule[i:i+(rule[i:].index(" "))].replace("\"", ""))
+
+            return priority
+
         attributes = []
         if default_zone is not None:
             if zone == default_zone:
@@ -398,10 +423,10 @@ class FirewallCommand(object):
                        ("yes" if icmp_block_inversion else "no"))
         self.print_msg("  interfaces: " + " ".join(interfaces))
         self.print_msg("  sources: " + " ".join(sources))
-        self.print_msg("  services: " + " ".join(services))
+        self.print_msg("  services: " + " ".join(sorted(services)))
         self.print_msg("  ports: " + " ".join(["%s/%s" % (port[0], port[1])
                                                for port in ports]))
-        self.print_msg("  protocols: " + " ".join(protocols))
+        self.print_msg("  protocols: " + " ".join(sorted(protocols)))
         self.print_msg("  masquerade: %s" % ("yes" if masquerade else "no"))
         self.print_msg("  forward-ports: " +
                        "\n\t".join(["port=%s:proto=%s:toport=%s:toaddr=%s" % \
@@ -412,7 +437,8 @@ class FirewallCommand(object):
                        " ".join(["%s/%s" % (port[0], port[1])
                                  for port in source_ports]))
         self.print_msg("  icmp-blocks: " + " ".join(icmp_blocks))
-        self.print_msg("  rich rules: \n\t" + "\n\t".join(rules))
+        self.print_msg("  rich rules: \n\t" + "\n\t".join(
+                            sorted(rules, key=rich_rule_sorted_key)))
 
     def print_service_info(self, service, settings):
         ports = settings.getPorts()
